/*
 * Copyright (C) 2002-2003 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.scrap;

import java.util.HashMap;
import java.util.Map;
import java.util.Observable;
import java.util.Iterator;

import org.jdom.Element;
import org.jdom.Attribute;

import com.intellij.openapi.project.Project;

/**
 * @author Sven Krause
 * @author Stefan Stiller
 * @version $Revision: 1.1 $, $Date: 2004/10/16 18:21:39 $
 */
public class ScrapConfig extends Observable
{
	private static Map instanceMap=new HashMap();

	public static ScrapConfig getInstance(Project project)
	{
		ScrapConfig instance=(ScrapConfig)instanceMap.get(project);
		if (instance==null)
		{
			instance=new ScrapConfig();
			instanceMap.put(project, instance);
		}
		return instance;
	}

	public static void closeInstance(Project project)
	{
		instanceMap.remove(project);
	}

	private Map confirmations=new HashMap();

	public Boolean getConfirmation(String key)
	{
		return (Boolean)confirmations.get(key);
	}

	public void setConfirmation(String key, Boolean value)
	{
		confirmations.put(key, value);
	}

	public void readExternal(Element element, Project project)
	{
		Element confirmationElement=element.getChild("confirmations");
		if (confirmationElement!=null)
		{
			for (Iterator it=confirmationElement.getAttributes().iterator(); it.hasNext();)
			{
				Attribute attribute=(Attribute)it.next();
				confirmations.put(attribute.getName(), new Boolean("true".equalsIgnoreCase(attribute.getValue())));
			}
		}
	}

	public void writeExternal(Element element, Project project)
	{
		Element confirmationElement=new Element("confirmations");
		for (Iterator it=confirmations.keySet().iterator(); it.hasNext();)
		{
			String key=(String)it.next();
			Boolean value=(Boolean)confirmations.get(key);
			if (value!=null) confirmationElement.setAttribute(key, value.toString());
		}
		element.addContent(confirmationElement);
	}
}
