/*
 * Copyright (C) 2002-2003 Stefan Stiller
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.kiwisoft.scrap;

import java.util.*;

import org.jdom.Element;

import com.intellij.openapi.project.Project;

import com.kiwisoft.utils.NotifyObject;
import com.kiwisoft.utils.StringUtils;
import com.kiwisoft.utils.Utils;

/**
 * @author Stefan Stiller
 * @version $Revision: 1.1 $, $Date: 2004/10/16 18:21:39 $
 */
public class ScrapManager extends Observable implements Observer
{
	private static Map instanceMap=new HashMap();

	private int scrapId=1;

	private List list;

	private ScrapManager()
	{
		list=new LinkedList();
	}

	public static ScrapManager getInstance(Project project)
	{
		ScrapManager instance=(ScrapManager)instanceMap.get(project);
		if (instance==null)
		{
			instance=new ScrapManager();
			instanceMap.put(project, instance);
		}
		return instance;
	}

	public static void closeInstance(Project project)
	{
		instanceMap.remove(project);
	}

	private String createScrapName()
	{
		String name="Scrap "+(scrapId++);
		while (getScrapByName(name)!=null) name="Scrap "+(scrapId++);
		return name;
	}

	public Scrap getScrapByName(String name)
	{
		for (Iterator it=list.iterator(); it.hasNext();)
		{
			Scrap scrap=(Scrap)it.next();
			if (name.equals(scrap.getName())) return scrap;
		}
		return null;
	}

	public Scrap createScrap()
	{
		Scrap scrap=new Scrap(createScrapName());
		addScrap(scrap);
		return scrap;
	}

	public Scrap createScrap(String text)
	{
		Scrap scrap=new Scrap(createScrapName(), text);
		addScrap(scrap);
		return scrap;
	}

	public Scrap createScrap(Scrap scrap)
	{
		Scrap clone=new Scrap(createScrapName(), scrap);
		addScrap(clone);
		return clone;
	}

	public void addScrap(Scrap scrap)
	{
		list.add(scrap);
		scrap.addObserver(this);
		setChanged();
		notifyObservers(new NotifyObject("scrap added", scrap));
	}

	public void removeScrap(Scrap scrap)
	{
		list.remove(scrap);
		scrap.deleteObserver(this);
		setChanged();
		notifyObservers(new NotifyObject("scrap removed", scrap));
	}

	public void update(Observable o, Object arg)
	{
		NotifyObject note=(NotifyObject)arg;
		Object type=note.getArgument(0);
		setChanged();
		notifyObservers(new NotifyObject("query "+type, o));
	}

	public void writeExternal(Element element)
	{
		Iterator it=list.iterator();
		while (it.hasNext())
		{
			Scrap scrap=(Scrap)it.next();
			if (scrap.getText()!=null)
			{
				Element child=new Element(Scrap.SCRAP);
				Utils.setValue(child, Scrap.NAME, scrap.getName());
				Element statementElement=new Element(Scrap.TEXT);
				statementElement.addContent(StringUtils.encodeURL(scrap.getText()));
				child.addContent(statementElement);
				element.addContent(child);
			}
		}
	}

	public void readExternal(Element element)
	{
		List scrapElements=element.getChildren(Scrap.SCRAP);
		if (scrapElements!=null)
		{
			Iterator it=scrapElements.iterator();
			while (it.hasNext())
			{
				Element scrapElement=(Element)it.next();
				Scrap scrap=new Scrap(scrapElement.getAttributeValue(Scrap.NAME));
				Element textElement=scrapElement.getChild(Scrap.TEXT);
				if (textElement!=null) scrap.setText(StringUtils.decodeURL(textElement.getText()));
				addScrap(scrap);
			}
		}
	}

	public List getScraps()
	{
		return Collections.unmodifiableList(list);
	}
}
